@@ -27,6 +27,9 @@ struct opt_out {
 	cl_uint device;
 	cl_bool selected;
 
+/* Specify that we should only print information about a specific property */
+	const char *prop;
+
 /* Specify if we should only be listing the platform and devices;
  * can be done in both human and raw mode, and only the platform
  * and device names (and number) will be shown
@@ -36,6 +39,10 @@ struct opt_out {
 	cl_bool brief;
 	cl_bool detailed; // !brief
 	cl_bool offline;
+
+/* JSON output for RAW */
+	cl_bool json;
+
 /* clGetDeviceInfo returns CL_INVALID_VALUE both for unknown properties
  * and when the destination variable is too small. Set the following to CL_TRUE
  * to check which one is the case
